.. _paster_module:

:mod:`pyramid.paster`
---------------------------

.. automodule:: pyramid.paster

    .. autofunction:: bootstrap

    .. autofunction:: get_app

    .. autofunction:: get_appsettings

    .. autofunction:: setup_logging
